@@ -283,20 +283,18 @@ impl Ditto {
         self.site_id
     }
 
-    /// Returns a custom identifier for the current device.
+    /// Set a custom identifier for the current device
     ///
     /// When using observePeers(), each remote peer is represented by a short
     /// UTF-8 “device name”. By default this will be a truncated version of
     /// the device’s hostname. It does not need to be unique among peers.
     /// Configure the device name before calling start(). If it is too long
     /// it will be truncated.
-    pub fn device_name(&self) -> &str {
-        todo!();
-    }
-
-    /// Set a custom identifier for the current device
-    pub fn set_device_name(&mut self, _name: String) {
-        todo!();
+    pub fn set_device_name(&self, name: &str) {
+        let c_device_name: char_p::Box = char_p::new(name.to_owned());
+        unsafe {
+            ffi_sdk::ditto_set_device_name(&self.ditto, c_device_name.as_ref());
+        }
     }
 
     /// Request bulk status information about the transports. This is mostly
