@@ -119,6 +119,17 @@ pub struct OnlinePlayground {
     auth_url: String,
 }
 
+/// Test a Ditto Cloud app with a simple shared token  ("Playground mode").
+/// This mode offers no security and must only be used for development.
+/// Other behavior mirrors the `Online` identity.
+pub struct OnlinePlaygroundV2 {
+    ditto_root: Arc<dyn DittoRoot>,
+    auth: DittoAuthenticator,
+    app_id: AppId,
+    enable_cloud_sync: bool,
+    auth_url: String,
+}
+
 /// An identity where any device is trusted provided they know the secret key.
 /// This is a simplistic authentication model normally only suitable for private
 /// apps where users and devices are both trusted. In this mode, any string may
@@ -716,6 +727,7 @@ impl OnlinePlayground {
     /// * `custom_auth_url` - An optional Alternative URL for authentication
     ///   requests. Defaults to
     /// `https://<app_id>.cloud.ditto.live/`
+    #[deprecated(note = "Use OnlinePlaygroundV2 instead")]
     pub fn new(
         ditto_root: Arc<dyn DittoRoot>,
         app_id: AppId,
@@ -800,10 +812,110 @@ impl Identity for OnlinePlayground {
     }
 }
 
+impl OnlinePlaygroundV2 {
+    /// Construct a new OnlinePlaygroundV2 identity.
+    /// * `ditto_root` - Instance of DittoRoot indicating local storage
+    ///   directory
+    /// * `app_id` - A unique AppId which must be a valid UUIDv4
+    /// * `shared_token` - A shared token used to set up the OnlinePlaygroundV2 session.  This token
+    ///         is provided by the portal when setting up the application.
+    /// * `enable_cloud_sync` - Should WebSocket sync with
+    ///   wss://<app_id>.cloud.ditto.live be
+    /// enabled by default. Do not enable this if you want to provide a custom
+    /// sync URL later
+    /// * `custom_auth_url` - An optional Alternative URL for authentication
+    ///   requests. Defaults to
+    /// `https://<app_id>.cloud.ditto.live/`
+    pub fn new(
+        ditto_root: Arc<dyn DittoRoot>,
+        app_id: AppId,
+        shared_token: String,
+        enable_cloud_sync: bool,
+        custom_auth_url: Option<&str>,
+    ) -> Result<Self, DittoError> {
+        let c_data_dir = ditto_root.data_dir_to_c_str()?;
+        let c_app_id = app_id.to_c_string();
+        let c_shared_token = char_p::new(shared_token.as_str());
+        let auth_url = match custom_auth_url {
+            Some(url) => url.to_owned(),
+            None => app_id.default_auth_url(),
+        };
+        let c_auth_url = char_p::new(auth_url.as_str());
+        let auth_client = unsafe {
+            ffi_sdk::ditto_auth_client_make_anonymous_client(
+                c_data_dir.as_ref(),
+                c_app_id.as_ref(),
+                c_shared_token.as_ref(),
+                c_auth_url.as_ref(),
+            )
+            .ok_or(ErrorKind::Config)?
+        };
+        let authenticator = DittoAuthenticator::new(Arc::new(auth_client));
+        Ok(Self {
+            ditto_root,
+            app_id,
+            auth: authenticator,
+            enable_cloud_sync,
+            auth_url,
+        })
+    }
+}
+
+impl Identity for OnlinePlaygroundV2 {
+    fn site_id(&self) -> SiteId {
+        unsafe { ffi_sdk::ditto_auth_client_get_site_id(&self.auth_client()) }
+    }
+
+    fn auth_client(&self) -> Arc<BoxedAuthClient> {
+        self.auth.auth_client()
+    }
+
+    fn app_id(&self) -> Option<&AppId> {
+        Some(&self.app_id)
+    }
+
+    fn ditto_root(&self) -> Arc<dyn DittoRoot> {
+        self.ditto_root.retain()
+    }
+
+    fn is_web_valid(&self) -> bool {
+        unsafe { ffi_sdk::ditto_auth_client_is_web_valid(&self.auth_client()) != 0 }
+    }
+
+    fn is_x509_valid(&self) -> bool {
+        unsafe { ffi_sdk::ditto_auth_client_is_x509_valid(&self.auth_client()) != 0 }
+    }
+
+    fn auth_url(&self) -> Result<String, DittoError> {
+        Ok(self.auth_url.to_owned())
+    }
+
+    fn sync_url(&self) -> Result<String, DittoError> {
+        Ok(self.app_id.default_sync_url())
+    }
+
+    fn authenticator(&self) -> Option<DittoAuthenticator> {
+        Some(self.auth.retain())
+    }
+
+    fn make_listener(&self, transports: Arc<RwLock<Transports>>) -> Option<Arc<ValidityListener>> {
+        Some(ValidityListener::new(transports, self.auth.auth_client()))
+    }
+
+    fn is_cloud_sync_enabled(&self) -> bool {
+        self.enable_cloud_sync
+    }
+
+    fn requires_offline_only_license_token(&self) -> bool {
+        false
+    }
+}
+
 mod private {
     use super::*;
     pub trait Sealed {}
     impl Sealed for OnlinePlayground {}
+    impl Sealed for OnlinePlaygroundV2 {}
     impl Sealed for Manual {}
     impl Sealed for Online {}
     impl Sealed for OnlineWithAuthentication {}
